BundleSessionInfoSnapshotById

Type Alias BundleSessionInfoSnapshotById 

pub type BundleSessionInfoSnapshotById = BTreeMap<String, UserInfo>;
info_change payloads use string keys from bundle_session_info_key integer and string user ids that stringify to the same key collide, so the later entry wins

Aliased Type

pub struct BundleSessionInfoSnapshotById { /* private fields */ }